import React from "react";

const Schema = ({ schema }) => {
  return (
    <>
      {/* Organizational Schema */}
      <script
        type="application/ld+json"
        dangerouslySetInnerHTML={{
          __html: `{
                    "@context": "https://schema.org/",
                    "@type": "Organization",
                    "name": "EaseToLearn",
                    "url": "https://www.easetolearn.com/",
                    "logo":{
                      "@type":"ImageObject",
                      "name": "EaseToLearn",
                      "url":"https://media.easetolearn.com/CompanyLogo.svg",
                      "width":600,
                      "height":60
                    },
                    "address": {
                      "@type": "PostalAddress",
                      "streetAddress": "1001-C, Westend Mall, Janakpuri, West Delhi",
                      "addressLocality": "Delhi",
                      "addressRegion": "India",
                      "postalCode": "110058"
                    },
                    "contactPoint":{
                      "@type": "ContactPoint",
                      "telephone": "+91 - 8178388120",
                      "email": "info@easetolearn.com",
                      "contactType": "Customer Service",
                      "areaServed": "IN",
                      "availableLanguage": "English"
                    },
                    "sameAs": [
                      "https://www.instagram.com/easetolearn_official/?hl=en",
                      "https://www.facebook.com/easetolearn",
                      "https://t.me/etlonlinelearning",
                      "https://www.linkedin.com/company/easetolearn/",
                      "https://twitter.com/easetolearn?lang=en"
                    ]
                }`,
        }}
      />

      {/* Breadcrumbs Schema */}
      {schema?.breadcrumbs && (
        <script
          type="application/ld+json"
          dangerouslySetInnerHTML={{
            __html: `{
                    "@context": "https://schema.org/",
                    "@type": "BreadcrumbList",
                    "itemListElement":[${schema?.breadcrumbs?.map(
                      (item, key) => {
                        return `
                          {
                            "@type":"ListItem",
                            "position": ${key + 1},
                            "item": {
                              "@id": "${item?.id}",
                              "name": "${item?.name}"
                            }
                          }`;
                      }
                    )}]
                  }`,
          }}
        />
      )}

      {/* Video schema for how it works */}
      {schema?.video && (
        <script
          type="application/ld+json"
          dangerouslySetInnerHTML={{
            __html: `
                    {
                      "@context": "https://schema.org/",
                      "@type": "VideoObject",
                      "name": "${schema?.video?.name}",
                      "@id": "${schema?.video?.url}",
                      "contentUrl": "${schema?.video?.url}",
                      "datePublished": "${schema?.video?.datePublished}",
                      "uploadDate": "${schema?.video?.uploadDate}",
                      "thumbnailUrl": "${schema?.video?.thumbnailUrl}",
                      "description": "${schema?.video?.description}",
                      "author": {
                        "@type": "Organization",
                        "name": "EaseToLearn"
                      }
                    }`,
          }}
        />
      )}

      {/* WebSite Schema */}
      {schema?.website && (
        <script
          type="application/ld+json"
          dangerouslySetInnerHTML={{
            __html: `{"@context": "https://schema.org/",
                    "@type": "WebSite",
                    "name": "EaseToLearn",
                    "url": "https://www.easetolearn.com/",
                    "potentialAction": {
                      "@type": "SearchAction",
                      "target": "https://www.easetolearn.com/courses{search_term_string}",
                      "query-input": "required name=search_term_string"
                    }}`,
          }}
        />
      )}

      {/* FaqPage Schema */}
      {schema?.faq && (
        <script
          type="application/ld+json"
          dangerouslySetInnerHTML={{
            __html: `{
                      "@context": "https://schema.org/",
                      "@type": "FAQPage",
                      "mainEntity": [
                        {
                          "@type": "Question",
                          "name": "What is ETL?",
                          "acceptedAnswer": {
                            "@type": "Answer",
                            "text": "Easetolearn.in is initiative to make learning easy and stress free by providing the world with a knowledge and skills acquiring method formulated by extensive research in the field of learning and education."
                          }
                        },
                        {
                          "@type": "Question",
                          "name": "What is the self assessor feature?",
                          "acceptedAnswer": {
                            "@type": "Answer",
                            "text": "This helps a student to know what is not known to the student in a topic. SELF ASSESSOR IS NOT A TESTING SYSTEM. It helps to identify gap in your knowledge. Suppose you do know answer to a question, pause the assessment and search the answer to that question from SMART LEARNING, books, internet, friends or teacher. This is the fastest and sure method of long-lasting learning. SELF ASSESSOR will invoke SMART LEARNING to help you find the answer. You must find the answer yourself."
                          }
                        },
                        {
                          "@type": "Question",
                          "name": "Are ETL services paid or free?",
                          "acceptedAnswer": {
                            "@type": "Answer",
                            "text": "❖ Smart Learning and Self Assessor are free of charge and can be accessed simply by 
                                      Signing Up.
                                    ❖ Exam Simulator is a paid service. In order to use Exam Simulator, kindly
                                    Contact Us"
                          }
                        },
                        {
                          "@type": "Question",
                          "name": "ETL services are available for students of which grades?",
                          "acceptedAnswer": {
                            "@type": "Answer",
                            "text": "ETL services are curated for students from 9th to 12th grades who wish to prepare for college/university entrance exams, study for the school curriculum or are curious to learn in general."
                          }
                        },
                        {
                          "@type": "Question",
                          "name": "How to learn via assessment in Self Assessor?",
                          "acceptedAnswer": {
                            "@type": "Answer",
                            "text": "Self Assessor has facility to simulate your own tests instantaneously for self assessment from vast number of subject, topics and keywords with flexibility to choose number of questions, type of questions, level of questions, allocate time and marks. Results of tests are instantaneous detailing given answers and correct answers."
                          }
                        },
                        {
                          "@type": "Question",
                          "name": "How to create an assessment in Self Assessor?",
                          "acceptedAnswer": {
                            "@type": "Answer",
                            "text": "Select Topic/subtopic or keyword you propose to create test on by clicking the topic/subtopic or doing a direct search for the keyword using the search box. Both the options cannot be used simultaneously."
                          }
                        }
                      ]
                  }`,
          }}
        />
      )}

      {/* Schema for Reviews */}
      {schema?.review && (
        <script
          type="application/ld+json"
          dangerouslySetInnerHTML={{
            __html: `{
                    "@context": "https://schema.org/",
                    "@type": "Review",
                    "itemReviewed": {
                      "@type": "Organization",
                      "name": "EaseToLearn",
                      "url": "https://www.easetolearn.com"
                    },
                    "reviewRating": {
                      "@type": "Rating",
                      "ratingValue": 5,
                      "worstRating": 1,
                      "bestRating": 5,
                      "reviewAspect": "Educational"
                    },
                    "reviewBody":"I have cleared Jee main this time..., paper was bit tough but easetolearn study material and practice sets never become burden and we can recall answers and teach them buy heart with explanation.",
                    "datePublished":"2022-05-22",
                    "author":{
                        "@type":"Person",
                        "name":"Preeti"
                    }
                  }`,
          }}
        />
      )}
    </>
  );
};

export default Schema;
