"use client";
import React, { useState, useEffect } from "react";

// Components
import WhiteLogo from "../Utils/SVGs/WhiteLogo";

// CSS
import styles from "./Header.module.css";
import HamburgerLogo from "../Utils/Logos/Hamburger/HamburgerLogo";

const Header = (props) => {
  // States
  const [hamburger, setHamburger] = useState(false);

  // useEffects
  useEffect(() => {
    /* 
    This is to prevent the overflow caused when the hamburger is opened.
    This fixes the height to 100vh and prevents overflow of the hamburger menu 
    */
    const body = document.querySelector(".sm_body")
    if(!hamburger) {
      body.style.height = "auto";
    } else {
      body.style.height = "100vh";
    }
  }, [hamburger])

  // Utilities
  const hamburgerClick = () => {
    // Toggle Hamburger
    setHamburger(!hamburger);
  };

  // Header
  return (
    <header className={`flex_display_between ${styles.sm_header}`}>
      {/* Main Logo */}
      <div className={`${styles.sm_header_logo}`}>
        <a href="https://easetolearn.com">
          <WhiteLogo />
        </a>
      </div>
      {/* Desktop Links */}
      <div className={`${styles.sm_header_links}`}>
        <ul>
          <li className={``}>
            <a href="https://easetolearn.com/courses/engineering">Courses</a>
          </li>
          <li className={``}>
            <a href="https://easetolearn.com/aboutus">About Us</a>
          </li>
          <li className={``}>
            <a href="https://easetolearn.com/student/login">Login</a>
          </li>
          <li className={`${styles.sm_yellow_button}`}>
            <a href="https://easetolearn.com/create-account">Join For Free</a>
          </li>
        </ul>
      </div>
      {/* Hamburger Menu */}
      <div className={`${styles.sm_hamburger_menu}`} onClick={hamburgerClick}>
        <HamburgerLogo expanded={hamburger} />
      </div>
      <div className={`${styles.sm_hamburger}`} aria-expanded={hamburger}>
        <div className={`${styles.sm_hamburger_container}`}>
          <ul>
            <li className={``}>
              <a href="https://easetolearn.com/courses/engineering">Courses</a>
            </li>
            <li className={``}>
              <a href="https://easetolearn.com/aboutus">About Us</a>
            </li>
            <li className={``}>
              <a href="https://easetolearn.com/student/login">Login</a>
            </li>
          </ul>
        </div>
      </div>
    </header>
  );
};

export default Header;
