// Core
import React from "react";

// Client Imports
import Schema from "../../../Client/Schema";
import Layout from "../../../Client/Layout";

// Bootstrap imports
import { Container, Col, Row } from "react-bootstrap";

// CSS
import styles from "./page.module.css";

// Server Side Data
import { getServerData } from "@/utils/http/getServerData";

// All MetaData
export async function generateMetadata({ params, searchParams }, parent) {
  let title = params?.route?.length > 0 ? params?.route[params?.route?.length - 1] : null
  if(title) {
    title = title?.split('-')?.map(country => country.charAt(0).toUpperCase() + country.substr(1))?.join(" ");
  }
  
  return {
    title: `${title} : Online Exam Preparation | Study Material`,
    description: "",
  };
}

export default async function Page({ params, searchParams }) {
  // Get the complete route
  const route =
    params?.route?.length > 1 ? params?.route?.join("/") : params?.route[0];

    // Call For server side api data
  const { data } = await getServerData({ slug: route });

  // Schema Obj
  const schema = {
    faq: true,
    website: true,
    review: true,
    video: {
      name: "How does EaseToLearn Work?",
      url: "https://www.youtube.com/watch?v=3lhkCUPAFOY&t=8s",
      datePublished: "2023-05-04",
      uploadDate: "2023-05-04",
      thumbnailUrl: "https://media.easetolearn.com/CompanyLogo.png",
      description: "Fastest method of learning for exams",
    },
  };

  return (
    <>
      <Schema schema={schema} />
      <Layout>
        <Container>
          <div className={styles?.sm_ad}>
            {/* <img
              className="desktop_display"
              src="/etl-sl/static/images/ad_banner.png"
              width={750}
              height={100}
              alt="banner ad"
            /> */}
          </div>
          <Row className={styles.sm_row}>
            <Col lg={9} className={styles.sm_col}>
              {data && data?.topic?.topic?.childnode_name ? (
                <div className={styles.sm_main_heading}>
                  <h1>{data?.topic?.topic?.childnode_name}</h1>
                </div>
              ) : (
                <></>
              )}

              {data?.topic && data?.topic?.topic?.image ? (
                <div className={styles.sm_main_image}>
                  <img
                    src={data?.topic?.topic?.image}
                    width={950}
                    alt="ETL SM Main Image"
                  />
                </div>
              ) : (
                <></>
              )}

              {data?.topic && data?.topic?.topic?.description ? (
                <div
                  className={styles.sm_story}
                  dangerouslySetInnerHTML={{
                    __html: data?.topic?.topic?.description,
                  }}
                />
              ) : (
                <></>
              )}

              {data?.content?.topics && data?.content?.topics?.length > 0 ? (
                <>
                  <h2 className={styles.sm_heading_two}>All Content</h2>
                  <div className={styles.sm_topics_container}>
                    {data?.content?.topics?.map((element, key) => {
                      const url =
                        element?.contentType === 1
                          ? `/smart-learning/video/${element?.slug}`
                          : element?.contentType === 2
                          ? `/smart-learning/pdf/${element?.slug}`
                          : element?.contentType === 3
                          ? `/smart-learning/ppt/${element?.slug}`
                          : element?.contentType === 4
                          ? `/smart-learning/web/${element?.slug}`
                          : "";
                      return (
                        <a
                          href={url}
                          key={key}
                          className={styles.sm_card_container}
                        >
                          <div className={styles.sm_card}>
                            <img
                              src={`${
                                element?.image
                                  ? element?.image
                                  : element?.contentType === 1
                                  ? "/etl-sl/static/images/video.svg"
                                  : element?.contentType === 2
                                  ? "/etl-sl/static/images/pdf.svg"
                                  : element?.contentType === 3
                                  ? "/etl-sl/static/images/ppt.svg"
                                  : element?.contentType === 4
                                  ? "/etl-sl/static/images/web.svg"
                                  : null
                              }`}
                              width={100}
                              alt="ETL content image"
                            />
                          </div>
                          <p>{element?.contentName}</p>
                        </a>
                      );
                    })}
                  </div>
                </>
              ) : (
                <></>
              )}

              {data?.subtopic?.subtopic &&
              data?.subtopic?.subtopic?.length > 0 ? (
                <>
                  <h2 className={styles.sm_heading_two}>Explore More Topics</h2>
                  <div className={styles.sm_topics_container}>
                    {data?.subtopic?.subtopic?.map((element, key) => {
                      return (
                        <a
                          href={`/smart-learning/${element?.topicMeta[0]?.slug}`}
                          key={key}
                          className={styles.sm_card_container}
                        >
                          <div className={styles.sm_card}>
                            <img
                              src={
                                element?.topicMeta[0]?.image
                                  ? element?.topicMeta[0]?.image
                                  : "/etl-sl/static/images/default.svg"
                              }
                              width={100}
                              alt="ETL content image"
                            />
                          </div>
                          <p>{element?.childnode_name}</p>
                        </a>
                      );
                    })}
                  </div>
                </>
              ) : (
                <></>
              )}
            </Col>
            <Col lg={3}>
              <div className={styles?.sm_ad}>
                {/* <img
                  src="/etl-sl/static/images/ad.png"
                  width={300}
                  height={250}
                  alt="banner ad"
                /> */}
              </div>
            </Col>
          </Row>
        </Container>
      </Layout>
    </>
  );
}
